#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.4.1
visibility:           public
id:                   pandoc-lua-engine-0.4.1-9b2QPP0B9DKIJ0ogqIHZTM
key:                  pandoc-lua-engine-0.4.1-9b2QPP0B9DKIJ0ogqIHZTM
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  86d75da48ba7555ddad1c0ed01bbc7b9
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Engine
    Text.Pandoc.Lua.Filter Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Module Text.Pandoc.Lua.Marshal.Chunks
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Run
    Text.Pandoc.Lua.SourcePos Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.4.1-9b2QPP0B9DKIJ0ogqIHZTM
depends:
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4 base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.2-hVyUkRzRuUCRPUhYqYN43
    containers-0.6.7 crypton-1.0.5-1z1P9gki3DpXKZxddhNPM
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    doclayout-0.5.0.1-J9yPtkMe54MGL10dwyqosD
    doctemplates-0.11.0.1-tPsIoonoxS195dlqymASh exceptions-0.10.7
    hslua-2.3.1-45hqtYI8UuD7sNkjFPNZQw
    hslua-module-doclayout-1.2.0.1-FPt12YmlEMd2zlcIoEfg3Q
    hslua-module-path-1.1.1-DvZpWVsMbbNIvzZt4nq1tH
    hslua-module-system-1.1.3-D23aDBMD7Lz4AHmAHjY2My
    hslua-module-text-1.1.1-6KERLttvjX3FZUK5PMXPsi
    hslua-module-version-1.1.1-DFZjECtSfgMAwenWDX7LUs
    hslua-module-zip-1.1.4-JFVhLdglDrAHJmnnIVkCsL
    hslua-repl-0.1.2-CUZQv9bGZN4IH2uYe6JCQZ
    lpeg-1.1.0.1-4GuVHeiLjvLEeLTkCdd5nJ mtl-2.3.1
    pandoc-3.6.1-3gMOnSYTaZTHFiOWwwmLAS
    pandoc-lua-marshal-0.3.1-E2WRmXPxLyH93i8aAF0BnH
    pandoc-types-1.23.1.1-KgMp7ipiwIdDM3OUvlIQe6 parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

